@@ -230,6 +230,8 @@ class TestCase(HttpRequest):
         :return:
         """
         search_value = jmespath.search(path, ResponseResult.response)
+        if isinstance(search_value, str):
+            search_value = int(search_value)
         assert search_value > value, f"{search_value} 不大于 {value}"
 
     def assertGe(self, path, value):
@@ -240,6 +242,8 @@ class TestCase(HttpRequest):
         :return:
         """
         search_value = jmespath.search(path, ResponseResult.response)
+        if isinstance(search_value, str):
+            search_value = int(search_value)
         assert search_value >= value, f"{search_value} 小于 {value}"
 
     def assertNotEq(self, path, value):
