@@ -21,7 +21,10 @@ def request(func):
 
         ResponseResult.method = func_name.upper()
         ResponseResult.path = url
-        base_url = conf.get_name('api', 'base_url')
+        try:
+            base_url = eval(conf.get_name('common', 'base_url'))
+        except:
+            base_url = None
         if (base_url is not None) and ("http" not in url):
             url = base_url + list(args)[1]
 
@@ -79,7 +82,7 @@ def request(func):
         try:
             resp = r.json()
             logger.debug(f"[type]: json \n")
-            logger.debug(f"[response]:\n {json_util.dumps(resp)} \n")
+            logger.debug(f"[response]:\n {resp} \n")
             ResponseResult.response = resp
         except BaseException as msg:
             logger.debug("[warning]: {} \n".format(msg))
@@ -104,34 +107,34 @@ class ResponseResult:
 class HttpRequest(object):
 
     @request
-    def get(self, url, params=None, **kwargs):
-        base_url = conf.get_name('api', 'base_url')
+    def get(self, url, params=None, login=True, **kwargs):
+        base_url = conf.get_name('common', 'base_url')
         if (base_url is not None) and ("http" not in url):
             url = base_url + url
-        return requests.get(url, params=params, verify=False, **kwargs)
+        return requests.get(url, params=params, **kwargs)
 
     @request
-    def post(self, url, data=None, json=None, **kwargs):
-        base_url = conf.get_name('api', 'base_url')
+    def post(self, url, data=None, json=None, login=True, **kwargs):
+        base_url = conf.get_name('common', 'base_url')
         if (base_url is not None) and ("http" not in url):
             url = base_url + url
-        return requests.post(url, data=data, json=json, verify=False, **kwargs)
+        return requests.post(url, data=data, json=json, **kwargs)
 
     @request
-    def put(self, url, data=None, json=None, **kwargs):
-        base_url = conf.get_name('api', 'base_url')
+    def put(self, url, data=None, json=None, login=True, **kwargs):
+        base_url = conf.get_name('common', 'base_url')
         if (base_url is not None) and ("http" not in url):
             url = base_url + url
         if json is not None:
             data = json_util.dumps(json)
-        return requests.put(url, data=data, verify=False, **kwargs)
+        return requests.put(url, data=data, **kwargs)
 
     @request
-    def delete(self, url, **kwargs):
-        base_url = conf.get_name('api', 'base_url')
+    def delete(self, url, login=True, **kwargs):
+        base_url = conf.get_name('common', 'base_url')
         if (base_url is not None) and ("http" not in url):
             url = base_url + url
-        return requests.delete(url, verify=False, **kwargs)
+        return requests.delete(url, **kwargs)
 
     @property
     def response(self):
