@@ -3,7 +3,6 @@ import json
 import os
 import sys
 import pytest
-import webbrowser
 from qrunner.utils.log import logger
 from qrunner.utils.config import conf
 
@@ -13,16 +12,17 @@ class TestMain(object):
     Support for app and web
     """
     def __init__(self,
-                 platform=None,
+                 platform='api',
                  serial_no=None,
                  pkg_name=None,
                  browser_name='chrome',
-                 case_path=None,
-                 rerun='0',
+                 case_path='test_dir',
+                 rerun=0,
                  concurrent=False,
                  base_url=None,
                  headers=None,
-                 timeout=None
+                 timeout=30,
+                 report_path='report'
                  ):
         """
         :param platform: 平台，如browser、android、ios、api
@@ -38,7 +38,7 @@ class TestMain(object):
             "signature": "xxxx"
         }
         :@param timeout: 接口请求超时时间
-        :@param show_report: 是否在浏览器中打开测试报告
+        :@param report_path: 报告生成目录
         """
 
         self.platform = platform
@@ -46,13 +46,12 @@ class TestMain(object):
         self.pkg_name = pkg_name
         self.browser_name = browser_name
         self.case_path = case_path
-        if isinstance(rerun, int):
-            self.rerun = str(rerun)
-        self.rerun = rerun
+        self.rerun = str(rerun)
         self.concurrent = concurrent
         self.base_url = base_url
         self.headers = headers
-        self.timeout = timeout
+        self.timeout = str(timeout)
+        self.report_path = report_path
 
         # 将数据写入全局变量
         if self.platform is not None:
@@ -64,15 +63,16 @@ class TestMain(object):
         if self.browser_name is not None:
             conf.set_name('web', 'browser_name', self.browser_name)
         if self.base_url is not None:
-            conf.set_name('api', 'base_url', self.base_url)
+            conf.set_name('common', 'base_url', self.base_url)
         else:
-            if self.platform == 'api':
+            if self.platform == 'api' or self.platform == 'browser':
                 print('base_url未配置，请配置后重新执行~')
                 sys.exit()
         if self.headers is not None:
             conf.set_name('api', 'headers', json.dumps(self.headers))
         if self.timeout is not None:
-            conf.set_name('api', 'timeout', self.timeout)
+            conf.set_name('common', 'timeout', self.timeout)
+        conf.set('common', 'report_path', self.report_path)
 
         # 执行用例
         logger.info('执行用例')
@@ -97,7 +97,7 @@ class TestMain(object):
 
         # 用例完成后操作
         conf.set_name('api', 'headers', json.dumps({}))  # 清除登录态
-        os.system('allure generate allure-results -o report --clean')  # 生成报告
+        os.system(f'allure generate allure-results -o {self.report_path} --clean')  # 生成报告
 
 
 main = TestMain
