@@ -20,6 +20,12 @@ class Config:
         with open(self.file_path, 'w') as f:
             self.cf.write(f)
 
+    def get(self, module, key):
+        return self.get_name(module, key)
+
+    def set(self, module, key, value):
+        self.set_name(module, key, value)
+
 
 conf = Config()
 
