@@ -5,11 +5,15 @@ import base64
 import urllib.parse
 import requests
 import json
+from qrunner.utils.allure_data import AllureData
 
 
 # 钉钉机器人
+from qrunner.utils.config import conf
+
+
 class Robot:
-    def __init__(self, secret, url):
+    def __init__(self, secret=None, url=None):
         self.secret = secret
         self.url = url
 
@@ -43,33 +47,38 @@ class Robot:
         else:
             print('消息发送失败: {}'.format(ret_dict.get('errmsg')))
 
+    # 从allure报告中获取数据并发送消息
+    def send_report(self, msg_title, report_url):
+        report_path = conf.get('common', 'report_path')
+        allure_data = AllureData(report_path).get_basic_info()
+        total = allure_data.get('total')
+        passed = allure_data.get('passed')
+        fail = allure_data.get('fail')
+        rate = allure_data.get('rate')
 
-if __name__ == '__main__':
-    # im测试群：im测试助手
-    robot_info_default = {
-        'secret': 'SECe0e8136eb7b81f712cb3b277cde794159c9ab24f3489b1d9f26629d79494403a',
-        'webhook_url': 'https://oapi.dingtalk.com/robot/send?access_token=487648aceb8a9e499673307c9647c2332599'
-                       'd0079a7a00c80ce5b1870b1a4b22'
-    }
-    r_secret = robot_info_default.get('secret')
-    r_url = robot_info_default.get('webhook_url')
+        color_red = 'FF0000'
+        color_green = '00FF00'
+        if rate < 100:
+            color_str = color_red
+        else:
+            color_str = color_green
 
-    # 默认消息内容
-    data_default = {
-        "msgtype": "markdown",
-        "markdown": {
-            "title": '测试',
-            "text": '测试123'
+        result_text = "### *{0}*\n\n" \
+                      "<font color=#C0C0C0>总数：</font>{1}，" \
+                      "<font color=#C0C0C0>通过：</font><font color=#C0C0C0>{2}，</font>\n" \
+                      "<font color=#C0C0C0>失败：</font><font color=#C0C0C0>{3}，</font>\n" \
+                      "<font color=#C0C0C0>成功率：</font><font color=#{4}>{5}%</font>\n" \
+                      "> #### [查看详情]({6})\n".format(msg_title, total, passed, fail, color_str, rate, report_url)
+        msg_data = {
+            "msgtype": "markdown",
+            "markdown": {
+                "title": msg_title,
+                "text": result_text
+            }
         }
-    }
 
-    # 消息拼接示例
-    # result_text = "### *{0}*\n\n" \
-    #     "<font color=#C0C0C0>用例数：</font>{1}，" \
-    #     "<font color=#C0C0C0>通过：</font><font color=#00FF00>{2}</font>，" \
-    #     "<font color=#C0C0C0>失败：</font><font color=#FF0000>{3}</font>，" \
-    #     "<font color=#C0C0C0>成功率：</font><font color=#00FF00>{4}%</font>\n" \
-    #     "> #### [查看详情]({5})\n".format(msg_title, total, pass_num, fail_num, pass_rate, url)
+        self.send_msg(msg_data)
+
+
+
 
-    robot = Robot(r_secret, r_url)
-    robot.send_msg(data_default)
