@@ -5,6 +5,10 @@ from email.header import Header
 
 
 # 邮件通知
+from qrunner.utils.allure_data import AllureData
+from qrunner.utils.config import conf
+
+
 class Mail:
     def __init__(self, host, user, password):
         self.host = host
@@ -46,21 +50,27 @@ class Mail:
         # 断开连接
         conn.quit()
 
+    def send_report(self, title, report_url, receiver_list):
+        report_path = conf.get('common', 'report_path')
+        allure_data = AllureData(report_path).get_basic_info()
+        total = allure_data.get('total')
+        fail = allure_data.get('fail')
+        passed = allure_data.get('passed')
+        rate = allure_data.get('rate')
 
-# 初始化
-mail = Mail('smtphm.qiye.163.com', 'kang.yang@qizhidao.com', 'WzQzd2019')
+        # 邮件内容
+        body_str = '\n\n共 {0} 个用例，通过 {1} 个，失败 {2} 个，通过率 {3}%，详见: {4}'\
+            .format(total, passed, fail, rate, report_url)
+        msg_data = {
+            'title': title,
+            'body': body_str,
+            'file_path': None,
+            'file_name': None
+        }
+
+        # 发送邮件
+        self.send_mail(msg_data, receiver_list)
 
 
-if __name__ == '__main__':
-    # 邮件内容
-    mail_data = {
-        'title': '测试邮件',
-        'body': '测试',
-        'file_path': None,
-        'file_name': None
-    }
-    # 收件人
-    receiver_list = ['kang.yang@qizhidao.com', 'kang.yang@qizhidao.com']
-    mail.send_mail(mail_data, receiver_list)
 
 
